/*
 * IdealIRC - Internet Relay Chat client
 * Copyright (C) 2019  Tom-Andre Barstad
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/

#ifndef SERVERITEM_H
#define SERVERITEM_H

#include <QString>
#include <QList>

class ServerItem
{
public:
	enum class Type {
		Root,
		Server,
		Network
	};

	/**
	 * @brief Construct a root item. Should only be constructed once as the "invisible" root item in the tree.
	*/
	explicit ServerItem();

	/**
	 * @brief Construct a server item. Set parentItem=nullptr for an orphaned server.
	*/
	ServerItem(ServerItem* parentItem, const QString& serverName, const QString& host, const quint16 port, const QString& password);

	/**
	 * @brief Construct a network item.
	*/
	ServerItem(const QString& networkName, const QString& host, const quint16 port, const QString& password);

	~ServerItem();

	Type getType() const;
	const QString& getNetworkName() const;
	const QString& getServerName() const;
	const QString& getHost() const;
	quint16 getPort() const;
	const QString& getPassword() const;
	ServerItem* getParentItem() const;
	bool isOrphan() const;

	bool addChild(ServerItem* child);
	bool delChild(ServerItem* child);
	ServerItem* getChild(int row) const;
	int childCount() const;
	int childRow(ServerItem* child) const;
	ServerItem* getParent() const;

private:
	Type m_type;
	QString m_networkName;
	QString m_serverName;
	QString m_host;
	quint16 m_port;
	QString m_password;
	ServerItem* m_parent{ nullptr };
	QList<ServerItem*> m_children;
};

#endif // SERVERITEM_H
