#include "IRCMember.h"
#include <algorithm>

IRCMember::IRCMember(const IRCPrefix& prefix)
	: m_prefix(prefix)
{}

IRCMember::IRCMember(const std::string& nickname)
	: m_prefix(IRCPrefix::fromNickname(nickname))
{}

const IRCPrefix& IRCMember::prefix() const
{
	return m_prefix;
}

void IRCMember::setPrefix(const IRCPrefix& prefix)
{
	m_prefix = prefix;
}

const std::vector<std::shared_ptr<IRCChannel>>& IRCMember::channels()
{
	return m_channels;
}

void IRCMember::addChannel(std::shared_ptr<IRCChannel> channel)
{
	auto it = std::find(m_channels.begin(), m_channels.end(), channel);
	if (it == m_channels.end())
		m_channels.emplace_back(channel);
}

void IRCMember::delChannel(std::shared_ptr<IRCChannel> channel)
{
	auto newEnd = std::remove(m_channels.begin(), m_channels.end(), channel);
	m_channels.erase(newEnd, m_channels.end());
}

void IRCMember::setNickname(const std::string& nickname)
{
	m_prefix.setNickname(nickname);
}
