#include "Error.h"
#include "Script/ScriptException.h"
#include <sstream>

namespace {
//! Add the "st"/"nd"/"rd"/"th" suffixes. Only supports values up to 20.
std::string ith(int i)
{
	std::string ret = std::to_string(i);
	switch (i) {
	case -1: [[fallthrough]];
	case 1:
		ret += "st";
		break;

	case -2: [[fallthrough]];
	case 2:
		ret += "nd";
		break;

	case -3: [[fallthrough]];
	case 3:
		ret += "rd";
		break;

	default:
		ret += "th";
	}
	return ret;
}
}

namespace Builtin::Error {

void throwInsufficientParameters(const std::string& fname, size_t given, size_t required)
{
	std::stringstream ss;
	ss << fname << ": Insufficient parameter count. "
		<< required << " required, " << given << " given";
	throw ScriptException(ss.str());
}

void throwNotAString(const std::string& fname, int paramPos)
{
	throw ScriptException(fname + ": " + ith(paramPos) + " parameter must be a string");
}

void throwNotANumber(const std::string& fname, int paramPos)
{
	throw ScriptException(fname + ": " + ith(paramPos) + " parameter must be a number");
}

void throwNotAWholeNumber(const std::string& fname, int paramPos)
{
	throw ScriptException(fname + ": " + ith(paramPos) + " parameter must be a whole number");
}

void throwNotADialogHandle(const std::string& fname, int paramPos)
{
	throw ScriptException(fname + ": " + ith(paramPos) + " parameter must be a dialog handle (a whole number)");
}

void throwNotAMap(const std::string& fname, int paramPos)
{
	throw ScriptException(fname + ": " + ith(paramPos) + " parameter must be a map");
}

void throwNotAList(const std::string& fname, int paramPos)
{
	throw ScriptException(fname + ": " + ith(paramPos) + " parameter must be a list");
}

void throwIndexOutOfRange(const std::string& fname, int paramPos)
{
	throw ScriptException(fname + ": " + ith(paramPos) + " parameter is out of range");
}


void throwNotAReference(const std::string& fname, int paramPos)
{
	throw ScriptException(fname + ": " + ith(paramPos) + " parameter must be a reference");
}

void throwNegativeInputUndefined(const std::string& fname)
{
	throw ScriptException(fname + ": Negative input is undefined");
}

void throwNumberMustBePositive(const std::string& fname, int paramPos)
{
	throw ScriptException(fname + ": " + ith(paramPos) + " parameter must be a positive number");
}

}
